Oh no, you encountered a problem while using *tsfesh*.

We, the maintainers, are happy to help you. When opening an issue, please provide the following information to us:

1. Your operating system
2. The version of *tsfresh* that you are using
3. The data on which the problem occurred (please do not upload 1000s of time series but try to boil the problem down to a small group or even a singular one)
4. A minimal code snippet which reproduces the problem/bug
5. Any reported errors or traceback

For questions, you can also use our [gitter chatroom](https://gitter.im/tsfresh/)
